==> zio-aws-sagemaker_2.12-7.21.15.3-sources.jar: zio/aws/sagemaker/model/DeleteImageVersionRequest.scala <==
package zio.aws.sagemaker.model
import zio.aws.sagemaker.model.primitives.{
  SageMakerImageVersionAlias,
  ImageVersionNumber,
  ImageName
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DeleteImageVersionRequest(
    imageName: ImageName,
    version: Optional[ImageVersionNumber] = Optional.Absent,
    alias: Optional[SageMakerImageVersionAlias] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.DeleteImageVersionRequest = {
    import DeleteImageVersionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.DeleteImageVersionRequest
      .builder()
      .imageName(ImageName.unwrap(imageName): java.lang.String)
      .optionallyWith(
        version.map(value => ImageVersionNumber.unwrap(value): Integer)
      )(_.version)
      .optionallyWith(
        alias.map(value =>
          SageMakerImageVersionAlias.unwrap(value): java.lang.String
        )
      )(_.alias)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.DeleteImageVersionRequest.ReadOnly =
    zio.aws.sagemaker.model.DeleteImageVersionRequest.wrap(buildAwsValue())
}
object DeleteImageVersionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.DeleteImageVersionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.DeleteImageVersionRequest =
      zio.aws.sagemaker.model.DeleteImageVersionRequest(
        imageName,
        version.map(value => value),
        alias.map(value => value)
      )
    def imageName: ImageName
    def version: Optional[ImageVersionNumber]
    def alias: Optional[SageMakerImageVersionAlias]
    def getImageName: ZIO[Any, Nothing, ImageName] = ZIO.succeed(imageName)
    def getVersion: ZIO[Any, AwsError, ImageVersionNumber] =
      AwsError.unwrapOptionField("version", version)
    def getAlias: ZIO[Any, AwsError, SageMakerImageVersionAlias] =
      AwsError.unwrapOptionField("alias", alias)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.DeleteImageVersionRequest
  ) extends zio.aws.sagemaker.model.DeleteImageVersionRequest.ReadOnly {
    override val imageName: ImageName =
      zio.aws.sagemaker.model.primitives.ImageName(impl.imageName())
    override val version: Optional[ImageVersionNumber] = zio.aws.core.internal
      .optionalFromNullable(impl.version())
      .map(value =>
        zio.aws.sagemaker.model.primitives.ImageVersionNumber(value)
      )
    override val alias: Optional[SageMakerImageVersionAlias] =
      zio.aws.core.internal
        .optionalFromNullable(impl.alias())
        .map(value =>
          zio.aws.sagemaker.model.primitives.SageMakerImageVersionAlias(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.DeleteImageVersionRequest
  ): zio.aws.sagemaker.model.DeleteImageVersionRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-sagemaker_2.13-5.17.164.1-sources.jar: zio/aws/sagemaker/model/DeleteImageVersionRequest.scala <==
package zio.aws.sagemaker.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.sagemaker.model.primitives.{ImageVersionNumber, ImageName}
import scala.jdk.CollectionConverters._
final case class DeleteImageVersionRequest(
    imageName: ImageName,
    version: ImageVersionNumber
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.DeleteImageVersionRequest = {
    import DeleteImageVersionRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.DeleteImageVersionRequest
      .builder()
      .imageName(ImageName.unwrap(imageName): java.lang.String)
      .version(ImageVersionNumber.unwrap(version): Integer)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.DeleteImageVersionRequest.ReadOnly =
    zio.aws.sagemaker.model.DeleteImageVersionRequest.wrap(buildAwsValue())
}
object DeleteImageVersionRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.DeleteImageVersionRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.DeleteImageVersionRequest =
      zio.aws.sagemaker.model.DeleteImageVersionRequest(imageName, version)
    def imageName: ImageName
    def version: ImageVersionNumber
    def getImageName: ZIO[Any, Nothing, ImageName] = ZIO.succeed(imageName)
    def getVersion: ZIO[Any, Nothing, ImageVersionNumber] = ZIO.succeed(version)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.DeleteImageVersionRequest
  ) extends zio.aws.sagemaker.model.DeleteImageVersionRequest.ReadOnly {
    override val imageName: ImageName =
      zio.aws.sagemaker.model.primitives.ImageName(impl.imageName())
    override val version: ImageVersionNumber =
      zio.aws.sagemaker.model.primitives.ImageVersionNumber(impl.version())
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.DeleteImageVersionRequest
  ): zio.aws.sagemaker.model.DeleteImageVersionRequest.ReadOnly = new Wrapper(
    impl
  )
}
